/*  GTKtalog.
 *  Copyright (C) 1999  Mathieu VILLEGAS
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __REPORT_H__
#define __REPORT_H__

#include <config.h>
#include <gnome.h>

typedef struct
{
}
REPORT_WIDGETS;

void _which_disk(GNode *gn, gpointer data);
void _report_cats(GNode *gn, gpointer data);
gboolean generate_cat_report(FOLDER * racine, FILE * file);
void _report_files(GNode *gn, gpointer data);
gboolean generate_file_report(FOLDER *racine, FILE * file);
void begin_report(GtkWidget *w, gpointer data);
void set_report_file(GtkWidget *w, gpointer data);
void select_report_file(GtkWidget *w, gpointer data);
void open_report_dialog (FOLDER *racine);

#endif
